==> slick-0.14.0.tar.gz: lib/controls/form_input/slick_number_input.dart <==
import 'package:slick/configuration/slick_configuration.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:google_fonts/google_fonts.dart';

class SlickNumberInput<T> extends StatelessWidget {
  SlickNumberInput({
    Key key,
    this.initialValue,
    this.labelText,
    @required this.onChanged,
    this.validator,
    this.padding = const EdgeInsets.only(
      top: 8.0,
      right: 8.0,
    ),
    this.width = 250,
    this.suffix,
    this.readOnly = false,
    this.prefix,
  }) : super(key: key);

  final T initialValue;
  final String labelText;
  final ValueChanged<T> onChanged;
  final FormFieldValidator<String> validator;
  final EdgeInsetsGeometry padding;
  final double width;
  final Widget suffix;
  final Widget prefix;
  final bool readOnly;

  @override
  Widget build(BuildContext context) {
    return Container(
      width: width,
      margin: padding,
      child: TextFormField(
        readOnly: readOnly,
        initialValue: initialValue.toString(),
        onChanged: processOnChanged,
        keyboardType: TextInputType.number,
        cursorColor: SlickConfiguration.colors.inputCursor,
        style: GoogleFonts.barlow(
          fontSize: 15,
          color: SlickConfiguration.colors.input,
        ),
        decoration: InputDecoration(
          suffix: suffix,
          prefix: prefix,
          enabledBorder: UnderlineInputBorder(
            borderSide: BorderSide(
              color: SlickConfiguration.colors.inputControlEnabledBorder,
              width: 0.2,
            ),
          ),
          focusedBorder: UnderlineInputBorder(
            borderSide: BorderSide(
              color: SlickConfiguration.colors.inputControlFocusedBorder,
            ),
          ),
          border: UnderlineInputBorder(
            borderSide: BorderSide(
              color: SlickConfiguration.colors.inputControlBorder,
            ),
          ),
          floatingLabelBehavior: FloatingLabelBehavior.always,
          labelText: labelText != null ? labelText.toUpperCase() : null,
          alignLabelWithHint: true,
          hintStyle: TextStyle(
            height: 2.0,
            color: SlickConfiguration.colors.input.withAlpha(150),
          ),
          hintText: labelText != null ? labelText.toUpperCase() : null,
          labelStyle: GoogleFonts.barlow(
            fontSize: 18,
            fontWeight: FontWeight.w600,
            color: SlickConfiguration.colors.inputLabel,
          ),
          errorStyle: GoogleFonts.barlow(
            fontSize: 12,
          ),
          filled: false,
        ),
        inputFormatters: <TextInputFormatter>[
          FilteringTextInputFormatter.allow(RegExp(r'^[0-9,]*$'))
        ], // Only numbers can be entered
        validator: validator,
      ),
    );
  }

  void processOnChanged(String val) {
    T result;
    if (T is int) {
      int v = int.tryParse(val);
      if (v == null) v = 0;
      result = v as T;
    }

    if (T is double) {
      double v = double.tryParse(val);
      if (v == null) v = 0;
      result = v as T;
    }

    onChanged(result);
  }
}

==> slick-0.19.0.tar.gz: lib/controls/form_input/slick_number_input.dart <==
import 'package:slick/configuration/slick_configuration.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:google_fonts/google_fonts.dart';

class SlickNumberInput<T> extends StatelessWidget {
  SlickNumberInput({
    Key key,
    @required this.initialValue,
    @required this.onChanged,
    this.labelText,
    this.validator,
    this.padding = const EdgeInsets.only(
      top: 8.0,
      right: 8.0,
    ),
    this.width = 250,
    this.suffix,
    this.readOnly = false,
    this.prefix,
  }) : super(key: key);

  final T initialValue;
  final String labelText;
  final ValueChanged<T> onChanged;
  final FormFieldValidator<String> validator;
  final EdgeInsetsGeometry padding;
  final double width;
  final Widget suffix;
  final Widget prefix;
  final bool readOnly;

  @override
  Widget build(BuildContext context) {
    return Container(
      width: width,
      margin: padding,
      child: TextFormField(
        readOnly: readOnly,
        initialValue: initialValue.toString(),
        onChanged: (value) {
          if (initialValue is int) {
            int v = int.tryParse(value);
            if (v == null) v = 0;
            this.onChanged(v as T);
          } else if (initialValue is double) {
            double v = double.tryParse(value);
            if (v == null) v = 0;
            this.onChanged(v as T);
          } else
            onChanged(value as T);
        },
        keyboardType: TextInputType.number,
        cursorColor: SlickConfiguration.colors.inputCursor,
        style: GoogleFonts.barlow(
          fontSize: 15,
          color: SlickConfiguration.colors.input,
        ),
        decoration: InputDecoration(
          suffix: suffix,
          prefix: prefix,
          enabledBorder: UnderlineInputBorder(
            borderSide: BorderSide(
              color: SlickConfiguration.colors.inputControlEnabledBorder,
              width: 0.2,
            ),
          ),
          focusedBorder: UnderlineInputBorder(
            borderSide: BorderSide(
              color: SlickConfiguration.colors.inputControlFocusedBorder,
            ),
          ),
          border: UnderlineInputBorder(
            borderSide: BorderSide(
              color: SlickConfiguration.colors.inputControlBorder,
            ),
          ),
          floatingLabelBehavior: FloatingLabelBehavior.always,
          labelText: labelText != null ? labelText.toUpperCase() : null,
          alignLabelWithHint: true,
          hintStyle: TextStyle(
            height: 2.0,
            color: SlickConfiguration.colors.input.withAlpha(150),
          ),
          hintText: labelText != null ? labelText.toUpperCase() : null,
          labelStyle: GoogleFonts.barlow(
            fontSize: 18,
            fontWeight: FontWeight.w600,
            color: SlickConfiguration.colors.inputLabel,
          ),
          errorStyle: GoogleFonts.barlow(
            fontSize: 12,
          ),
          filled: false,
        ),
        inputFormatters: <TextInputFormatter>[
          FilteringTextInputFormatter.allow(RegExp(r'^[0-9,]*$')),
        ],
        validator: validator,
      ),
    );
  }
}
